@@ -100,7 +100,7 @@ chxj_exchange_chtml30(
   chxj_dump_out("[src] CHTML -> CHTML3.0", ss, srclen);
 #endif
 
-  qs_parse_string(&doc,ss);
+  qs_parse_string(&doc,ss, strlen(ss));
 
   /*--------------------------------------------------------------------------*/
   /* It converts it from CHTML to CHTML.                                      */
@@ -145,6 +145,7 @@ chxj_init_chtml30(Chtml30* chtml30, Doc* doc, request_rec* r, device_table* spec
   chtml30->spec = spec;
   chtml30->out  = qs_alloc_zero_byte_string(r);
   chtml30->conf = ap_get_module_config(r->per_dir_config, &chxj_module);
+  chtml30->doc->parse_mode = PARSE_MODE_CHTML;
 }
 
 /**
