@@ -20,6 +20,7 @@
 #include <unistd.h>
 #include "chxj_img_conv.h"
 #include "chxj_dump.h"
+
 #define CHECK_BOX_PREFIX     "_chxj_c_"
 #define RADIO_BUTTON_PREFIX  "_chxj_r_"
 #define SUBMIT_BUTTON_PREFIX "_chxj_s_"
@@ -95,9 +96,6 @@ chxj_exchange_hdml(request_rec* r,
   char*     buf = NULL;
   Doc       doc;
   Hdml      hdml;
-  void*     shm_segment;
-  int*      shm;
-  mod_chxj_global_config* gconf;
 
   /*--------------------------------------------------------------------------*/
   /* initialize hdml structure                                                */
@@ -144,10 +142,12 @@ chxj_exchange_hdml(request_rec* r,
     /* Here, the parsing of the received character string is done             */
     /*------------------------------------------------------------------------*/
     char *ss = apr_pstrdup(r->pool, src);
+    ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r,
+                    "input srclen=[%d]\n", srclen);
     qs_init_malloc(&doc); 
     qs_init_root_node(&doc);
     ss[srclen] = '\0';
-    qs_parse_string(&doc,ss);
+    qs_parse_string(&doc, ss, srclen);
 
     /*------------------------------------------------------------------------*/
     /* The number of radiobuttons is counted.                                 */
@@ -178,21 +178,6 @@ chxj_exchange_hdml(request_rec* r,
 
   *dstlen = hdml.out_len;
 
-  /*--------------------------------------------------------------------------*/
-  /* for HDML Counter                                                         */
-  /*--------------------------------------------------------------------------*/
-  gconf = ap_get_module_config(r->server->module_config, &chxj_module);
-
-  apr_global_mutex_lock(gconf->client_lock);
-  shm_segment = apr_shm_baseaddr_get(gconf->client_shm);
-  shm = (int*)shm_segment;
-  hdml.form_cnt = *shm;
-  *shm = hdml.form_cnt + hdml.pure_form_cnt + 1;
-  ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r,
-                  "form_cnt[%d] -> [%d]", hdml.form_cnt,
-                                          *shm);
-  apr_global_mutex_unlock(gconf->client_lock); 
-
   /*--------------------------------------------------------------------------*/
   /* Null is set at the end of the character string to make sure.             */
   /*--------------------------------------------------------------------------*/
@@ -215,9 +200,6 @@ chxj_init_hdml(Hdml* hdml, Doc* doc, request_rec* r, device_table* spec)
 {
   int     ii;
   int     jj;
-  void*   shm_segment;
-  int*    shm;
-  mod_chxj_global_config* gconf;
 
   /*--------------------------------------------------------------------------*/
   /* init hdml structure value                                                */
@@ -227,6 +209,7 @@ chxj_init_hdml(Hdml* hdml, Doc* doc, request_rec* r, device_table* spec)
   hdml->card     = qs_alloc_zero_byte_string(r);
   hdml->spec     = spec;
   hdml->conf     = ap_get_module_config(r->per_dir_config, &chxj_module);
+  hdml->doc->parse_mode = PARSE_MODE_CHTML;
 
   for (ii=0; ii<MAX_FORM_COUNT; ii++) 
   {
@@ -253,16 +236,7 @@ chxj_init_hdml(Hdml* hdml, Doc* doc, request_rec* r, device_table* spec)
 
   doc->r               = r;
 
-  /*--------------------------------------------------------------------------*/
-  /* for HDML Counter                                                         */
-  /*--------------------------------------------------------------------------*/
-  gconf = ap_get_module_config(r->server->module_config, &chxj_module);
-  apr_global_mutex_lock(gconf->client_lock);
-  shm_segment = apr_shm_baseaddr_get(gconf->client_shm);
-  shm = (int*)shm_segment;
-  hdml->form_cnt = *shm;
-  apr_global_mutex_unlock(gconf->client_lock); 
-
+  hdml->form_cnt = apr_time_now();
   hdml->out = qs_alloc_zero_byte_string(r);
 }
 
@@ -1371,7 +1345,7 @@ hdml_do_input_text_tag(Hdml* hdml, Node* tag)
   hdml->card_cnt++;
   qs_output_to_hdml_out(hdml, 
                   apr_psprintf(r->pool,
-                          "<A TASK=GOSUB LABEL= DEST=#D%d "
+                          "<A TASK=GOSUB LABEL=\x93\xfc\x97\xcd DEST=#D%d "
                           "VARS=\"V=$%s%02d\" RECEIVE=%s%02d>",
                           hdml->card_cnt,
                           qs_get_form_no(r, hdml),
@@ -1479,7 +1453,7 @@ hdml_do_input_password_tag(Hdml* hdml, Node* tag)
   hdml_tag_output_upper_half(hdml, tag);
 
   hdml->card_cnt++;
-  qs_output_to_hdml_out(hdml, "<A TASK=GOSUB LABEL= DEST="              );
+  qs_output_to_hdml_out(hdml, "<A TASK=GOSUB LABEL=\"\x93\xfc\x97\xcd\" DEST=");
   qs_output_to_hdml_out(hdml, apr_psprintf(r->pool, "#D%d ", hdml->card_cnt));
   qs_output_to_hdml_out(hdml, 
                   apr_psprintf(r->pool, "VARS=\"V=$%s%02d\" ", 
@@ -1490,7 +1464,10 @@ hdml_do_input_password_tag(Hdml* hdml, Node* tag)
                   apr_psprintf(r->pool, "RECEIVE=%s%02d>"  , 
                           qs_get_form_no(r, hdml),
                           hdml->var_cnt[hdml->pure_form_cnt]));
-  qs_output_to_hdml_out(hdml, "[****]</A>\n"          );
+  qs_output_to_hdml_out(hdml, 
+                  apr_psprintf(r->pool, "[$%s%02d]</A>\n"  , 
+                          qs_get_form_no(r, hdml),
+                          hdml->var_cnt[hdml->pure_form_cnt]));
 
   qs_output_to_hdml_card(hdml, "<ENTRY NAME="                               );
   qs_output_to_hdml_card(hdml, apr_psprintf(r->pool, "D%d ", hdml->card_cnt));
@@ -1697,7 +1674,7 @@ hdml_do_input_radio_tag(Hdml* hdml, Node* tag)
   qs_output_to_hdml_out(hdml, 
                   apr_psprintf(r->pool, 
                           "<A TASK=GOSUB "
-                          "LABEL=\"\" "
+                          "LABEL=\"\x93\xfc\x97\xcd\" "
                           "DEST=#R%d VARS=\"VAL=%s\" "
                           "RECEIVE=\"%s;", 
                           ii, 
@@ -1883,7 +1860,7 @@ hdml_do_input_checkbox_tag(Hdml* hdml, Node* tag)
     nm   = qs_alloc_zero_byte_string(r);
   }
   qs_output_to_hdml_out(hdml, apr_psprintf(r->pool, 
-                                "<A TASK=GOSUB LABEL=\"\" "
+                                "<A TASK=GOSUB LABEL=\"a\xaf\xb8\" "
                                    "DEST=\"#$%s%02d\" "
                                    "VARS=\"V=%s\" "
                                    "RECEIVE=\"%s%02d;%s%02d;%s%02d\">"
@@ -2060,7 +2037,7 @@ hdml_1_0_start_hr_tag(Hdml* hdml, Node* node)
     }
   }
 
-  qs_output_to_hdml_out(hdml, "<CENTER><BR>\n");
+  qs_output_to_hdml_out(hdml, "<CENTER>\x81\x7c\x81\x7c\x81\x7c\x81\x7c\x81\x7c\x81\x7c\x81\x7c\x81\x7c\x81\x7c<BR>\n");
 
   hdml->hdml_br_flag = 1;
 
@@ -2200,7 +2177,7 @@ hdml_1_0_start_select_tag(Hdml* hdml, Node* node)
   hdml->card_cnt++;
 
   qs_output_to_hdml_out(hdml, apr_psprintf(r->pool, 
-                                   "<A TASK=GOSUB LABEL=I "
+                                   "<A TASK=GOSUB LABEL=\x91\x49\x91\xf0 "
                                    "VARS=\"V=$%s%02d\" DEST=#D%d "
                                    "RECEIVE=\"%s%02d;%s%02d\">"
                                    "$%s%02d</A>\n",
@@ -2473,14 +2450,17 @@ static char*
 qs_get_form_no(request_rec* r, Hdml* hdml) 
 {
   char *result;
-  int  fc = hdml->form_cnt + hdml->pure_form_cnt;
+  apr_time_exp_t tm;
+  unsigned long fc = hdml->form_cnt;
 
-  result = apr_pcalloc(r->pool, 4);
-  memset(result, 0, 4);
+  apr_time_exp_tz(&tm, hdml->form_cnt, 0);
 
-  result[0] = 'A' + ((fc / 100) % 26);
+  result = apr_psprintf(r->pool, "%c",(int)('A' + ((fc / 100) % 26)));
   result = apr_pstrcat(r->pool, result, 
-                  apr_psprintf(r->pool, "%02d", (fc % 100)), NULL);
+                  apr_psprintf(r->pool, "%02d%02d%02d", 
+                          tm.tm_hour,
+                          tm.tm_min,
+                          tm.tm_sec), NULL);
   return result;
 }
 
