@@ -98,7 +98,7 @@ chxj_exchange_jhtml(
 #ifdef DUMP_LOG
   chxj_dump_out("[src] CHTML -> JHTML", ss, srclen);
 #endif
-  qs_parse_string(&doc,ss);
+  qs_parse_string(&doc,ss,strlen(ss));
 
   /*--------------------------------------------------------------------------*/
   /* It converts it from CHTML to JHTML.                                      */
@@ -143,6 +143,7 @@ chxj_init_jhtml(Jhtml* jhtml, Doc* doc, request_rec* r, device_table* spec)
   jhtml->spec = spec;
   jhtml->out  = qs_alloc_zero_byte_string(r);
   jhtml->conf = ap_get_module_config(r->per_dir_config, &chxj_module);
+  jhtml->doc->parse_mode = PARSE_MODE_CHTML;
 }
 
 /**
