@@ -85,7 +85,9 @@ chxj_exchange_xhtml_mobile_1_0(
   /*--------------------------------------------------------------------------*/
   /* The XHTML structure is initialized.                                      */
   /*--------------------------------------------------------------------------*/
+  ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r,"start chxj_exchange_xhtml_mobile_1_0()");
   chxj_init_xhtml(&xhtml, &doc, r, spec);
+  ap_set_content_type(r, "text/html; charset=Windows-31J");
 
   /*--------------------------------------------------------------------------*/
   /* The character string of the input is analyzed.                           */
@@ -100,7 +102,9 @@ chxj_exchange_xhtml_mobile_1_0(
 #ifdef DUMP_LOG
   chxj_dump_out("[src] CHTML->XHTML", ss, srclen);
 #endif
-  qs_parse_string(&doc,ss);
+  ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r,"start parse");
+  qs_parse_string(&doc,ss, strlen(ss));
+  ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r,"end parse");
 
   /*--------------------------------------------------------------------------*/
   /* It converts it from CHTML to XHTML.                                      */
@@ -121,6 +125,7 @@ chxj_exchange_xhtml_mobile_1_0(
 #ifdef DUMP_LOG
   chxj_dump_out("[dst] CHTML->XHTML", dst, *dstlen);
 #endif
+  ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r,"end chxj_exchange_xhtml_mobile_1_0()");
   return dst;
 }
 
@@ -145,6 +150,7 @@ chxj_init_xhtml(Xhtml* xhtml, Doc* doc, request_rec* r, device_table* spec)
   xhtml->spec = spec;
   xhtml->out  = qs_alloc_zero_byte_string(r);
   xhtml->conf = ap_get_module_config(r->per_dir_config, &chxj_module);
+  xhtml->doc->parse_mode = PARSE_MODE_CHTML;
 }
 
 /**
@@ -346,6 +352,11 @@ xhtml_1_0_node_exchange(Xhtml* xhtml, Node* node, int indent)
       ap_log_rerror(APLOG_MARK, APLOG_DEBUG,0,r, "chxj:if tag found");
       if (chxj_chxjif_is_mine(xhtml->spec, doc, child))
       {
+        char* destlang = qs_get_destlang_attr(doc, child, r);
+        if (destlang != NULL && strcasecmp(destlang, "hdml") == 0)
+        {
+          ap_set_content_type(r, "text/x-hdml; charset=Shift_JIS");
+        }
         ap_log_rerror(APLOG_MARK, APLOG_DEBUG,0,r, "chxj:if tag is mine");
         xhtml_1_0_chxjif_tag(xhtml, child);
       }
