@@ -15,8 +15,11 @@
  * limitations under the License.
  */
 #include <unistd.h>
+#include <string.h>
+
 #include "httpd.h"
 #include "http_config.h"
+#include "http_core.h"
 #include "http_protocol.h"
 #include "http_log.h"
 #include "ap_config.h"
@@ -28,15 +31,16 @@
 #include "apr_dso.h"
 #include "apr_general.h"
 #include "apr_pools.h"
-#include <string.h>
+#include "ap_regex.h"
+
 #include "mod_chxj.h"
-#include <qs_ignore_sp.h>
-#include <qs_log.h>
-#include <qs_malloc.h>
-#include <qs_parse_attr.h>
-#include <qs_parse_file.h>
-#include <qs_parse_string.h>
-#include <qs_parse_tag.h>
+#include "qs_ignore_sp.h"
+#include "qs_log.h"
+#include "qs_malloc.h"
+#include "qs_parse_attr.h"
+#include "qs_parse_file.h"
+#include "qs_parse_string.h"
+#include "qs_parse_tag.h"
 #include "chxj_load_device_data.h"
 #include "chxj_load_emoji_data.h"
 #include "chxj_specified_device.h"
@@ -48,6 +52,9 @@
 #include "chxj_chtml30.h"
 #include "chxj_jhtml.h"
 
+#include "chxj_img_conv_format.h"
+
+
 #ifdef PACKAGE_NAME
 #undef PACKAGE_NAME
 #endif
@@ -69,14 +76,6 @@
 #define CHXJ_VERSION_PREFIX PACKAGE_NAME "/"
 #define CHXJ_VERSION        PACKAGE_VERSION
 
-
-#define DEF_SHMEM_SIZE  (4)
-
-static long shmem_size  = DEF_SHMEM_SIZE;
-
-static const char* HTTP_USER_AGENT = "User-Agent";
-
-
 /**
  * It converts it from CHTML into ML corresponding to each model. 
  *
@@ -119,6 +118,7 @@ chxj_exchange(request_rec *r, const char** src, apr_size_t* len)
       dst = chxj_exchange_chtml10(r, spec, *src, *len, len);
       *len = strlen(dst);
       ap_set_content_type(r, "text/html; charset=Windows-31J");
+
     }
     else
     if (spec->html_spec_type == CHXJ_SPEC_Chtml_2_0) 
@@ -173,7 +173,6 @@ chxj_exchange(request_rec *r, const char** src, apr_size_t* len)
       ap_log_rerror(APLOG_MARK,APLOG_DEBUG, 0, r, "select XHTML Mobile 1.0");
       dst = chxj_exchange_xhtml_mobile_1_0(r, spec, *src, *len, len);
       *len = strlen(dst);
-      ap_set_content_type(r, "text/html; charset=Windows-31J");
     }
     else
     if (spec->html_spec_type == CHXJ_SPEC_Hdml) 
@@ -487,7 +486,7 @@ chxj_input_filter(ap_filter_t*        f,
   char*               data_bucket;
   char*               data_brigade;
 
-  ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "start of chxj_input_fileter()");
+  ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "start of chxj_input_filter()");
 
   data_brigade = qs_alloc_zero_byte_string(r);
 
@@ -535,7 +534,7 @@ chxj_input_filter(ap_filter_t*        f,
   {
     ap_log_rerror(APLOG_MARK, APLOG_DEBUG, rv, r,
                     "data_brigade length is 0");
-    ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "end of chxj_input_fileter()");
+    ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "end of chxj_input_filter()");
     ap_remove_input_filter(f);
     return ap_get_brigade(f->next, bb, mode, block, readbytes);
   }
@@ -552,7 +551,7 @@ chxj_input_filter(ap_filter_t*        f,
     APR_BRIGADE_INSERT_TAIL(obb, eos);
     APR_BRIGADE_CONCAT(bb, obb);
   }
-  ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "end of chxj_input_fileter()");
+  ap_log_rerror(APLOG_MARK, APLOG_DEBUG, 0, r, "end of chxj_input_filter()");
   return APR_SUCCESS;
 }
 
@@ -577,25 +576,6 @@ chxj_init_module_kill(void *data)
   /*--------------------------------------------------------------------------*/
   conf = ap_get_module_config(base_server->module_config, &chxj_module);
 
-  /*--------------------------------------------------------------------------*/
-  /* The shared memory is liberated.                                          */
-  /*--------------------------------------------------------------------------*/
-  if (conf != NULL&& conf->client_shm != NULL) 
-  {
-    apr_shm_destroy(conf->client_shm);
-    conf->client_shm = NULL;
-    ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, base_server, 
-                  "destroy shared memory.");
-  }
-
-  if (conf != NULL && conf->client_lock != NULL)
-  {
-    apr_global_mutex_destroy(conf->client_lock);
-    conf->client_lock = NULL;
-    ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, base_server, 
-                  "destroy mutex.");
-  }
-
   ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, base_server, 
                   "end chxj_init_module_kill()");
   return APR_SUCCESS;
@@ -604,10 +584,6 @@ chxj_init_module_kill(void *data)
 static mod_chxj_global_config*
 chxj_global_config_create(apr_pool_t* pool, server_rec* s)
 {
-  apr_status_t    sts;
-  void*           shm_segment;
-  apr_size_t      shm_segsize;
-  int*            shm;
   mod_chxj_global_config* conf;
   void*           param;
 
@@ -617,7 +593,6 @@ chxj_global_config_create(apr_pool_t* pool, server_rec* s)
 
   apr_pool_userdata_get(&param, CHXJ_MOD_CONFIG_KEY, pool);
   conf = (mod_chxj_global_config*)param;
-
   apr_pool_cleanup_register(pool, s,
                                chxj_init_module_kill,
                                apr_pool_cleanup_null);
@@ -640,48 +615,6 @@ chxj_global_config_create(apr_pool_t* pool, server_rec* s)
   conf->client_lock = NULL;
   memset(conf->client_lock_file_name, 0, sizeof(conf->client_lock_file_name));
 
-  /*--------------------------------------------------------------------------*/
-  /* Let us cleanup on restarts and exists                                    */
-  /*--------------------------------------------------------------------------*/
-
-
-  sts = apr_shm_create(&conf->client_shm, shmem_size, tmpnam(NULL), pool);
-  if (sts != APR_SUCCESS) 
-  {
-    ap_log_error(APLOG_MARK, APLOG_ERR, 0, s, 
-                   "chxj_init_module Shared memory securing failure");
-    _exit(1);
-  }
-
-  shm_segment = apr_shm_baseaddr_get(conf->client_shm);
-  shm_segsize = apr_shm_size_get(conf->client_shm);
-
-  ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, s,
-                 "chxj_init_module allocated %" APR_SIZE_T_FMT
-                 " bytes of shared memory",
-                 shm_segsize);
-
-  ap_log_error(APLOG_MARK, APLOG_INFO, 0, s,
-                 "Shared memory hdml counter initialised");
-
-  shm = (int*)shm_segment;
-  *shm = 0;
-
-  ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, s, "shm:[%d]", *shm);
-
-  sts = apr_global_mutex_create(&conf->client_lock, 
-                  tmpnam(conf->client_lock_file_name), 
-                  APR_LOCK_DEFAULT, pool);
-  ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, s, "mutex create end [%s]", conf->client_lock_file_name);
-  if (sts != APR_SUCCESS) 
-  {
-    ap_log_error(APLOG_MARK, APLOG_ERR, 0, s,
-                    "chxj_init_module Lock initialization failure");
-    chxj_init_module_kill((void*)s);
-    _exit(1);
-  }
-  ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, s,
-                  "lock file:[%s]", conf->client_lock_file_name);
 
   apr_pool_userdata_set(conf, CHXJ_MOD_CONFIG_KEY,
                               apr_pool_cleanup_null,
@@ -699,8 +632,6 @@ chxj_init_module(apr_pool_t *p,
                   apr_pool_t *ptemp, 
                   server_rec *s)
 {
-  mod_chxj_global_config* conf;
-
   ap_log_error(APLOG_MARK, APLOG_DEBUG, 0, s,
                   "start chxj_init_module()");
 
@@ -721,11 +652,23 @@ chxj_config_server_create(apr_pool_t *p, server_rec *s)
 {
   mod_chxj_global_config *gc;
 
-  gc = chxj_global_config_create(p, s);
+  gc = chxj_global_config_create(p,s);
 
   return gc;
 }
 
+static int chxj_convert_images(request_rec *r)
+{
+  return chxj_img_conv_format(r);
+}
+
+
+static int
+chxj_translate_name(request_rec *r)
+{
+  return chxj_trans_name(r);
+}
+
 /**
  * The hook is registered.
  *
@@ -748,10 +691,8 @@ chxj_register_hooks(apr_pool_t *p)
                       chxj_input_filter, 
                       NULL, 
                       AP_FTYPE_RESOURCE);
-#if 0
-                      AP_FTYPE_CONNECTION);
-                      AP_FTYPE_PROTOCOL);
-#endif
+  ap_hook_handler(chxj_convert_images, NULL, NULL, APR_HOOK_MIDDLE);
+  ap_hook_translate_name(chxj_translate_name, NULL, NULL, APR_HOOK_MIDDLE);
 }
 
 /**
@@ -767,8 +708,12 @@ chxj_create_per_dir_config(apr_pool_t *p, char *arg)
 
   conf = apr_pcalloc(p, sizeof(mod_chxj_config));
   conf->device_data_file = NULL;
+  conf->emoji_data_file  = NULL;
+  conf->image_uri        = NULL;
+  conf->image_cache_dir  = apr_psprintf(p, "%s",DEFAULT_IMAGE_CACHE_DIR);
 
-
+  /* Default is copyleft */
+  conf->image_copyright = NULL; 
   return conf;
 }
 
@@ -835,6 +780,55 @@ cmd_load_emoji_data(cmd_parms *parms, void *mconfig, const char* arg)
   return rtn;
 }
 
+static const char* 
+cmd_set_image_uri(cmd_parms *parms, void *mconfig, const char* arg) 
+{
+  mod_chxj_config* conf;
+  Doc doc;
+  doc.r = NULL;
+  if (strlen(arg) > 256) 
+  {
+    return "image uri is too long.";
+  }
+
+  conf = (mod_chxj_config*)mconfig;
+  conf->image_uri = apr_pstrdup(parms->pool, arg);
+  return NULL;
+}
+
+static const char* 
+cmd_set_image_cache_dir(cmd_parms *parms, void *mconfig, const char* arg) 
+{
+  mod_chxj_config* conf;
+  Doc doc;
+  doc.r = NULL;
+  if (strlen(arg) > 256) 
+  {
+    return "cache dir name is too long.";
+  }
+
+  conf = (mod_chxj_config*)mconfig;
+  conf->image_cache_dir = apr_pstrdup(parms->pool, arg);
+  return NULL;
+}
+
+static const char* 
+cmd_set_image_copyright(cmd_parms *parms, void *mconfig, const char* arg) 
+{
+  mod_chxj_config* conf;
+  Doc doc;
+
+  doc.r = NULL;
+  if (strlen(arg) > 256) 
+  {
+    return "Copyright Flag is too long.";
+  }
+
+  conf = (mod_chxj_config*)mconfig;
+  conf->image_copyright = apr_pstrdup(parms->pool, arg);
+  return NULL;
+}
+
 static const command_rec cmds[] = {
   AP_INIT_TAKE1(
     "ChxjLoadDeviceData",
@@ -848,6 +842,24 @@ static const command_rec cmds[] = {
     NULL,
     OR_ALL,
     "Load Emoji Data"),
+  AP_INIT_TAKE1(
+    "ChxjImageUri",
+    cmd_set_image_uri,
+    NULL,
+    OR_ALL,
+    "Convert Target URI"),
+  AP_INIT_TAKE1(
+    "ChxjImageCacheDir",
+    cmd_set_image_cache_dir,
+    NULL,
+    OR_ALL,
+    "Image Cache Directory"),
+  AP_INIT_TAKE1(
+    "ChxjImageCopyright",
+    cmd_set_image_copyright,
+    NULL,
+    OR_ALL,
+    "Copyright Flag"),
   { NULL },
 };
 
